#ifndef _SOX_SRC_SOXSTDINT_H
#define _SOX_SRC_SOXSTDINT_H 1
#ifndef _GENERATED_STDINT_H
#define _GENERATED_STDINT_H "sox 14.0.0"
/* generated using gnu compiler gcc (GCC) 4.1.2 */
#define _STDINT_HAVE_STDINT_H 1
#include <stdint.h>
#endif
#endif
