( cd usr/bin ; rm -rf play )
( cd usr/bin ; ln -sf sox play )
( cd usr/bin ; rm -rf rec )
( cd usr/bin ; ln -sf sox rec )
( cd usr/lib ; rm -rf libsox.so.0 )
( cd usr/lib ; ln -sf libsox.so.0.0.0 libsox.so.0 )
( cd usr/lib ; rm -rf libsfx.so.0 )
( cd usr/lib ; ln -sf libsfx.so.0.0.0 libsfx.so.0 )
( cd usr/lib ; rm -rf libsfx.so )
( cd usr/lib ; ln -sf libsfx.so.0.0.0 libsfx.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_wav.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_wav.so.0.0.0 libsox_fmt_wav.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_nul.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_nul.so.0.0.0 libsox_fmt_nul.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_raw.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_raw.so.0.0.0 libsox_fmt_raw.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_wve.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_wve.so.0.0.0 libsox_fmt_wve.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_sf.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_sf.so.0.0.0 libsox_fmt_sf.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_lpc10.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_lpc10.so.0.0.0 libsox_fmt_lpc10.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_vorbis.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_vorbis.so.0.0.0 libsox_fmt_vorbis.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_lu.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_lu.so.0.0.0 libsox_fmt_lu.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_u1.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_u1.so.0.0.0 libsox_fmt_u1.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_wve.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_wve.so.0.0.0 libsox_fmt_wve.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_dat.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_dat.so.0.0.0 libsox_fmt_dat.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_sf.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_sf.so.0.0.0 libsox_fmt_sf.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_lpc10.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_lpc10.so.0.0.0 libsox_fmt_lpc10.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_sndfile.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_sndfile.so.0.0.0 libsox_fmt_sndfile.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_xa.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_xa.so.0.0.0 libsox_fmt_xa.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_aifc.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_aifc.so.0.0.0 libsox_fmt_aifc.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_cvsd.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_cvsd.so.0.0.0 libsox_fmt_cvsd.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_s4.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_s4.so.0.0.0 libsox_fmt_s4.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_u4.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_u4.so.0.0.0 libsox_fmt_u4.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_mp3.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_mp3.so.0.0.0 libsox_fmt_mp3.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_s3.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_s3.so.0.0.0 libsox_fmt_s3.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_hcom.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_hcom.so.0.0.0 libsox_fmt_hcom.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_svx.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_svx.so.0.0.0 libsox_fmt_svx.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_la.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_la.so.0.0.0 libsox_fmt_la.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_vorbis.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_vorbis.so.0.0.0 libsox_fmt_vorbis.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_sndrtool.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_sndrtool.so.0.0.0 libsox_fmt_sndrtool.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_sphere.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_sphere.so.0.0.0 libsox_fmt_sphere.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_maud.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_maud.so.0.0.0 libsox_fmt_maud.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_ao.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_ao.so.0.0.0 libsox_fmt_ao.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_vox.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_vox.so.0.0.0 libsox_fmt_vox.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_ao.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_ao.so.0.0.0 libsox_fmt_ao.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_maud.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_maud.so.0.0.0 libsox_fmt_maud.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_au.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_au.so.0.0.0 libsox_fmt_au.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_aiff.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_aiff.so.0.0.0 libsox_fmt_aiff.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_vox.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_vox.so.0.0.0 libsox_fmt_vox.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_svx.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_svx.so.0.0.0 libsox_fmt_svx.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_u2.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_u2.so.0.0.0 libsox_fmt_u2.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_s1.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_s1.so.0.0.0 libsox_fmt_s1.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_dat.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_dat.so.0.0.0 libsox_fmt_dat.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_voc.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_voc.so.0.0.0 libsox_fmt_voc.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_la.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_la.so.0.0.0 libsox_fmt_la.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_cdr.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_cdr.so.0.0.0 libsox_fmt_cdr.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_sphere.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_sphere.so.0.0.0 libsox_fmt_sphere.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_aiff.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_aiff.so.0.0.0 libsox_fmt_aiff.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_s3.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_s3.so.0.0.0 libsox_fmt_s3.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_flac.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_flac.so.0.0.0 libsox_fmt_flac.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_alsa.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_alsa.so.0.0.0 libsox_fmt_alsa.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_lu.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_lu.so.0.0.0 libsox_fmt_lu.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_s2.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_s2.so.0.0.0 libsox_fmt_s2.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_alsa.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_alsa.so.0.0.0 libsox_fmt_alsa.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_cdr.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_cdr.so.0.0.0 libsox_fmt_cdr.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_wav.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_wav.so.0.0.0 libsox_fmt_wav.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_mp3.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_mp3.so.0.0.0 libsox_fmt_mp3.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_dvms.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_dvms.so.0.0.0 libsox_fmt_dvms.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_avr.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_avr.so.0.0.0 libsox_fmt_avr.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_smp.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_smp.so.0.0.0 libsox_fmt_smp.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_u3.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_u3.so.0.0.0 libsox_fmt_u3.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_s1.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_s1.so.0.0.0 libsox_fmt_s1.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_flac.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_flac.so.0.0.0 libsox_fmt_flac.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_s2.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_s2.so.0.0.0 libsox_fmt_s2.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_auto.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_auto.so.0.0.0 libsox_fmt_auto.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_nul.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_nul.so.0.0.0 libsox_fmt_nul.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_u4.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_u4.so.0.0.0 libsox_fmt_u4.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_gsm.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_gsm.so.0.0.0 libsox_fmt_gsm.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_raw.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_raw.so.0.0.0 libsox_fmt_raw.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_avr.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_avr.so.0.0.0 libsox_fmt_avr.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_gsm.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_gsm.so.0.0.0 libsox_fmt_gsm.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_u3.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_u3.so.0.0.0 libsox_fmt_u3.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_prc.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_prc.so.0.0.0 libsox_fmt_prc.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_ul.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_ul.so.0.0.0 libsox_fmt_ul.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_al.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_al.so.0.0.0 libsox_fmt_al.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_cvsd.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_cvsd.so.0.0.0 libsox_fmt_cvsd.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_u1.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_u1.so.0.0.0 libsox_fmt_u1.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_voc.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_voc.so.0.0.0 libsox_fmt_voc.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_sndfile.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_sndfile.so.0.0.0 libsox_fmt_sndfile.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_ima.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_ima.so.0.0.0 libsox_fmt_ima.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_u2.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_u2.so.0.0.0 libsox_fmt_u2.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_aifc.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_aifc.so.0.0.0 libsox_fmt_aifc.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_auto.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_auto.so.0.0.0 libsox_fmt_auto.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_oss.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_oss.so.0.0.0 libsox_fmt_oss.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_txw.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_txw.so.0.0.0 libsox_fmt_txw.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_al.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_al.so.0.0.0 libsox_fmt_al.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_hcom.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_hcom.so.0.0.0 libsox_fmt_hcom.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_xa.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_xa.so.0.0.0 libsox_fmt_xa.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_sndrtool.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_sndrtool.so.0.0.0 libsox_fmt_sndrtool.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_txw.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_txw.so.0.0.0 libsox_fmt_txw.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_s4.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_s4.so.0.0.0 libsox_fmt_s4.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_dvms.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_dvms.so.0.0.0 libsox_fmt_dvms.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_ima.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_ima.so.0.0.0 libsox_fmt_ima.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_prc.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_prc.so.0.0.0 libsox_fmt_prc.so.0 )
( cd usr/lib/sox ; rm -rf libsox_fmt_au.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_au.so.0.0.0 libsox_fmt_au.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_smp.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_smp.so.0.0.0 libsox_fmt_smp.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_oss.so )
( cd usr/lib/sox ; ln -sf libsox_fmt_oss.so.0.0.0 libsox_fmt_oss.so )
( cd usr/lib/sox ; rm -rf libsox_fmt_ul.so.0 )
( cd usr/lib/sox ; ln -sf libsox_fmt_ul.so.0.0.0 libsox_fmt_ul.so.0 )
( cd usr/lib ; rm -rf libsox.so )
( cd usr/lib ; ln -sf libsox.so.0.0.0 libsox.so )
( cd usr/man/man1 ; rm -rf play.1 )
( cd usr/man/man1 ; ln -sf sox.1 play.1 )
( cd usr/man/man1 ; rm -rf rec.1 )
( cd usr/man/man1 ; ln -sf sox.1 rec.1 )
